Machine
-------

A :class:`gordo.machine.Machine` is the central unity of a model, dataset, metadata and everything
needed to create and build a ML model.

.. automodule:: gordo.machine.machine
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: gordo.machine.encoders
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: gordo.machine.constants
    :members:
    :undoc-members:
    :show-inheritance: